==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/ListTransfers.java <==
package de.fzj.unicore.ucc.actions;

import java.util.Iterator;

import org.w3.x2005.x08.addressing.EndpointReferenceDocument;

import de.fzj.unicore.uas.client.EnumerationClient;
import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.uas.client.TSSClient;
import de.fzj.unicore.uas.client.TransferControllerClient;
import de.fzj.unicore.ucc.helpers.StorageLister;
import de.fzj.unicore.ucc.helpers.TargetSystemLister;
import de.fzj.unicore.ucc.util.UnitParser;

/**
 * lists server-to-server transfers
 *
 * @author schuller
 */
public class ListTransfers extends ListActionBase<TransferControllerClient> {

	public String getName(){
		return "list-transfers";
	}

	protected UnitParser unitParser=UnitParser.getCapacitiesParser(0);

	@Override
	public void process() {
		super.process();
		for(TSSClient c: new TargetSystemLister(registry,securityProperties,this)){
			for(StorageClient sms: new StorageLister(c,securityProperties,this)){
				verbose("Storage : "+sms.getUrl());
				try{
					listFiletransfers(sms);
				}catch(Exception ex){
					error("Error listing storage at "+sms.getEPR().getAddress().getStringValue(), ex);
				}
			};
		}
		for(StorageClient sms: new StorageLister(registry,securityProperties,this)){
			verbose("Storage : "+sms.getUrl());	
			try{
				listFiletransfers(sms);
			}catch(Exception ex){
				error("Error listing storage at "+sms.getEPR().getAddress().getStringValue(), ex);
			}
		};
	}

	protected void listFiletransfers(StorageClient sms)throws Exception{
		EnumerationClient<EndpointReferenceDocument>ftEnumeration=sms.getFiletransferEnumeration();
		if(ftEnumeration==null)return;
		Iterator<EndpointReferenceDocument> fts=ftEnumeration.iterator();
		while(fts.hasNext()){
			EndpointReferenceDocument eprd=fts.next();
			TransferControllerClient ftc=new TransferControllerClient(eprd.getEndpointReference(), securityProperties);
			if(filterMatch(ftc)){
				listFiletransfer(ftc);
				lastNumberOfResults++;
			}
		}
	}

	protected void listFiletransfer(TransferControllerClient ftc){
		try{
			message(ftc.getUrl()+getDetails(ftc));
		}catch(Exception ex){
			error("Error listing filetransfer at "+ftc.getUrl(), ex);
		}
		printWSRFProperties(ftc);
	}

	@Override
	protected String getDetails(TransferControllerClient ftc) {
		if(!detailed)return "";
		StringBuilder sb=new StringBuilder();
		try{
			sb.append(" ");
			sb.append(ftc.getStatus());
			sb.append(" ");
			sb.append(unitParser.getHumanReadable(ftc.getTransferredBytes()));
			sb.append("/");
			sb.append(unitParser.getHumanReadable(ftc.getSize()));
		}catch(Exception ex){}
		return sb.toString();
	}

	@Override
	public String getDescription(){
		return "list the available remote storages";
	}
	@Override
	public String getArgumentList(){
		return "";
	}
	@Override
	public String getCommandGroup(){
		return "General";
	}

}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/ListTransfers.java <==
package de.fzj.unicore.ucc.actions;

import java.util.Iterator;

import org.w3.x2005.x08.addressing.EndpointReferenceDocument;

import de.fzj.unicore.uas.client.EnumerationClient;
import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.uas.client.TSSClient;
import de.fzj.unicore.uas.client.TransferControllerClient;
import de.fzj.unicore.ucc.helpers.StorageLister;
import de.fzj.unicore.ucc.helpers.TargetSystemLister;
import de.fzj.unicore.ucc.util.UnitParser;

/**
 * lists server-to-server transfers
 *
 * @author schuller
 */
public class ListTransfers extends ListActionBase<TransferControllerClient> {

	public String getName(){
		return "list-transfers";
	}

	protected UnitParser unitParser=UnitParser.getCapacitiesParser(0);

	@Override
	public void process() {
		super.process();
		for(TSSClient c: new TargetSystemLister(registry,securityProperties,this)){
			for(StorageClient sms: new StorageLister(c,securityProperties,this)){
				verbose("Storage : "+sms.getUrl());
				try{
					listFiletransfers(sms);
				}catch(Exception ex){
					error("Error listing storage at "+sms.getEPR().getAddress().getStringValue(), ex);
				}
			};
		}
		for(StorageClient sms: new StorageLister(registry,securityProperties,this)){
			verbose("Storage : "+sms.getUrl());	
			try{
				listFiletransfers(sms);
			}catch(Exception ex){
				error("Error listing storage at "+sms.getEPR().getAddress().getStringValue(), ex);
			}
		};
	}

	protected void listFiletransfers(StorageClient sms)throws Exception{
		EnumerationClient<EndpointReferenceDocument>ftEnumeration=sms.getFiletransferEnumeration();
		if(ftEnumeration==null)return;
		Iterator<EndpointReferenceDocument> fts=ftEnumeration.iterator();
		while(fts.hasNext()){
			EndpointReferenceDocument eprd=fts.next();
			TransferControllerClient ftc=new TransferControllerClient(eprd.getEndpointReference(), securityProperties);
			if(filterMatch(ftc)){
				listFiletransfer(ftc);
				lastNumberOfResults++;
			}
		}
	}

	protected void listFiletransfer(TransferControllerClient ftc){
		try{
			message(ftc.getUrl()+getDetails(ftc));
		}catch(Exception ex){
			error("Error listing filetransfer at "+ftc.getUrl(), ex);
		}
		printWSRFProperties(ftc);
	}

	@Override
	protected String getDetails(TransferControllerClient ftc) {
		if(!detailed)return "";
		StringBuilder sb=new StringBuilder();
		try{
			sb.append(" ");
			sb.append(ftc.getStatus());
			sb.append(" ");
			sb.append(unitParser.getHumanReadable(ftc.getTransferredBytes()));
			sb.append("/");
			sb.append(unitParser.getHumanReadable(ftc.getSize()));
		}catch(Exception ex){}
		return sb.toString();
	}

	@Override
	public String getDescription(){
		return "list the server-to-server transfers";
	}
	@Override
	public String getArgumentList(){
		return "";
	}
	@Override
	public String getCommandGroup(){
		return "General";
	}

}
